==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkDuplicateSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NetworkDuplicateSpecFluent<A extends NetworkDuplicateSpecFluent<A>> extends BaseFluent<A>{
  public NetworkDuplicateSpecFluent() {
  }
  
  public NetworkDuplicateSpecFluent(NetworkDuplicateSpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String device;
  private String egressPort;
  private String hostname;
  private String ipAddress;
  private String ipProtocol;
  private String percent;
  private String sourcePort;
  
  protected void copyInstance(NetworkDuplicateSpec instance) {
    instance = (instance != null ? instance : new NetworkDuplicateSpec());
    if (instance != null) {
          this.withCorrelation(instance.getCorrelation());
          this.withDevice(instance.getDevice());
          this.withEgressPort(instance.getEgressPort());
          this.withHostname(instance.getHostname());
          this.withIpAddress(instance.getIpAddress());
          this.withIpProtocol(instance.getIpProtocol());
          this.withPercent(instance.getPercent());
          this.withSourcePort(instance.getSourcePort());
          this.withCorrelation(instance.getCorrelation());
          this.withDevice(instance.getDevice());
          this.withEgressPort(instance.getEgressPort());
          this.withHostname(instance.getHostname());
          this.withIpAddress(instance.getIpAddress());
          this.withIpProtocol(instance.getIpProtocol());
          this.withPercent(instance.getPercent());
          this.withSourcePort(instance.getSourcePort());
        }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation = correlation;
    return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getDevice() {
    return this.device;
  }
  
  public A withDevice(String device) {
    this.device = device;
    return (A) this;
  }
  
  public boolean hasDevice() {
    return this.device != null;
  }
  
  public String getEgressPort() {
    return this.egressPort;
  }
  
  public A withEgressPort(String egressPort) {
    this.egressPort = egressPort;
    return (A) this;
  }
  
  public boolean hasEgressPort() {
    return this.egressPort != null;
  }
  
  public String getHostname() {
    return this.hostname;
  }
  
  public A withHostname(String hostname) {
    this.hostname = hostname;
    return (A) this;
  }
  
  public boolean hasHostname() {
    return this.hostname != null;
  }
  
  public String getIpAddress() {
    return this.ipAddress;
  }
  
  public A withIpAddress(String ipAddress) {
    this.ipAddress = ipAddress;
    return (A) this;
  }
  
  public boolean hasIpAddress() {
    return this.ipAddress != null;
  }
  
  public String getIpProtocol() {
    return this.ipProtocol;
  }
  
  public A withIpProtocol(String ipProtocol) {
    this.ipProtocol = ipProtocol;
    return (A) this;
  }
  
  public boolean hasIpProtocol() {
    return this.ipProtocol != null;
  }
  
  public String getPercent() {
    return this.percent;
  }
  
  public A withPercent(String percent) {
    this.percent = percent;
    return (A) this;
  }
  
  public boolean hasPercent() {
    return this.percent != null;
  }
  
  public String getSourcePort() {
    return this.sourcePort;
  }
  
  public A withSourcePort(String sourcePort) {
    this.sourcePort = sourcePort;
    return (A) this;
  }
  
  public boolean hasSourcePort() {
    return this.sourcePort != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkDuplicateSpecFluent that = (NetworkDuplicateSpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
    if (!java.util.Objects.equals(device, that.device)) return false;
    if (!java.util.Objects.equals(egressPort, that.egressPort)) return false;
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;
    if (!java.util.Objects.equals(ipAddress, that.ipAddress)) return false;
    if (!java.util.Objects.equals(ipProtocol, that.ipProtocol)) return false;
    if (!java.util.Objects.equals(percent, that.percent)) return false;
    if (!java.util.Objects.equals(sourcePort, that.sourcePort)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  device,  egressPort,  hostname,  ipAddress,  ipProtocol,  percent,  sourcePort,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (egressPort != null) { sb.append("egressPort:"); sb.append(egressPort + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ipAddress != null) { sb.append("ipAddress:"); sb.append(ipAddress + ","); }
    if (ipProtocol != null) { sb.append("ipProtocol:"); sb.append(ipProtocol + ","); }
    if (percent != null) { sb.append("percent:"); sb.append(percent + ","); }
    if (sourcePort != null) { sb.append("sourcePort:"); sb.append(sourcePort); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> chaosmesh-model-7.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/NetworkDuplicateSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NetworkDuplicateSpecFluent<A extends NetworkDuplicateSpecFluent<A>> extends BaseFluent<A>{
  public NetworkDuplicateSpecFluent() {
  }
  
  public NetworkDuplicateSpecFluent(NetworkDuplicateSpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String device;
  private String egressPort;
  private String hostname;
  private String ipAddress;
  private String ipProtocol;
  private String percent;
  private String sourcePort;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(NetworkDuplicateSpec instance) {
    instance = (instance != null ? instance : new NetworkDuplicateSpec());
    if (instance != null) {
          this.withCorrelation(instance.getCorrelation());
          this.withDevice(instance.getDevice());
          this.withEgressPort(instance.getEgressPort());
          this.withHostname(instance.getHostname());
          this.withIpAddress(instance.getIpAddress());
          this.withIpProtocol(instance.getIpProtocol());
          this.withPercent(instance.getPercent());
          this.withSourcePort(instance.getSourcePort());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation = correlation;
    return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getDevice() {
    return this.device;
  }
  
  public A withDevice(String device) {
    this.device = device;
    return (A) this;
  }
  
  public boolean hasDevice() {
    return this.device != null;
  }
  
  public String getEgressPort() {
    return this.egressPort;
  }
  
  public A withEgressPort(String egressPort) {
    this.egressPort = egressPort;
    return (A) this;
  }
  
  public boolean hasEgressPort() {
    return this.egressPort != null;
  }
  
  public String getHostname() {
    return this.hostname;
  }
  
  public A withHostname(String hostname) {
    this.hostname = hostname;
    return (A) this;
  }
  
  public boolean hasHostname() {
    return this.hostname != null;
  }
  
  public String getIpAddress() {
    return this.ipAddress;
  }
  
  public A withIpAddress(String ipAddress) {
    this.ipAddress = ipAddress;
    return (A) this;
  }
  
  public boolean hasIpAddress() {
    return this.ipAddress != null;
  }
  
  public String getIpProtocol() {
    return this.ipProtocol;
  }
  
  public A withIpProtocol(String ipProtocol) {
    this.ipProtocol = ipProtocol;
    return (A) this;
  }
  
  public boolean hasIpProtocol() {
    return this.ipProtocol != null;
  }
  
  public String getPercent() {
    return this.percent;
  }
  
  public A withPercent(String percent) {
    this.percent = percent;
    return (A) this;
  }
  
  public boolean hasPercent() {
    return this.percent != null;
  }
  
  public String getSourcePort() {
    return this.sourcePort;
  }
  
  public A withSourcePort(String sourcePort) {
    this.sourcePort = sourcePort;
    return (A) this;
  }
  
  public boolean hasSourcePort() {
    return this.sourcePort != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NetworkDuplicateSpecFluent that = (NetworkDuplicateSpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
    if (!java.util.Objects.equals(device, that.device)) return false;
    if (!java.util.Objects.equals(egressPort, that.egressPort)) return false;
    if (!java.util.Objects.equals(hostname, that.hostname)) return false;
    if (!java.util.Objects.equals(ipAddress, that.ipAddress)) return false;
    if (!java.util.Objects.equals(ipProtocol, that.ipProtocol)) return false;
    if (!java.util.Objects.equals(percent, that.percent)) return false;
    if (!java.util.Objects.equals(sourcePort, that.sourcePort)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  device,  egressPort,  hostname,  ipAddress,  ipProtocol,  percent,  sourcePort,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (device != null) { sb.append("device:"); sb.append(device + ","); }
    if (egressPort != null) { sb.append("egressPort:"); sb.append(egressPort + ","); }
    if (hostname != null) { sb.append("hostname:"); sb.append(hostname + ","); }
    if (ipAddress != null) { sb.append("ipAddress:"); sb.append(ipAddress + ","); }
    if (ipProtocol != null) { sb.append("ipProtocol:"); sb.append(ipProtocol + ","); }
    if (percent != null) { sb.append("percent:"); sb.append(percent + ","); }
    if (sourcePort != null) { sb.append("sourcePort:"); sb.append(sourcePort + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
